package cn.com.infosec.asn1.x509.qualified;

import cn.com.infosec.asn1.ASN1Choice;
import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERPrintableString;

public class Iso4217CurrencyCode extends ASN1Encodable implements ASN1Choice {
   final int ALPHABETIC_MAXSIZE = 3;
   final int NUMERIC_MINSIZE = 1;
   final int NUMERIC_MAXSIZE = 999;
   DEREncodable obj;
   int numeric;

   public static Iso4217CurrencyCode getInstance(Object obj) {
      if (obj != null && !(obj instanceof Iso4217CurrencyCode)) {
         if (obj instanceof DERInteger) {
            int obj2 = DERInteger.getInstance(obj).getValue().intValue();
            return new Iso4217CurrencyCode(obj2);
         } else if (obj instanceof DERPrintableString) {
            DERPrintableString obj1 = DERPrintableString.getInstance(obj);
            return new Iso4217CurrencyCode(obj1.getString());
         } else {
            throw new IllegalArgumentException("unknown object in getInstance");
         }
      } else {
         return (Iso4217CurrencyCode)obj;
      }
   }

   public Iso4217CurrencyCode(int numeric) {
      if (numeric <= 999 && numeric >= 1) {
         Iso4217CurrencyCode var10000 = this;
         DERInteger var2;
         var2 = new DERInteger.<init>(numeric);
         var10000.obj = var2;
      } else {
         throw new IllegalArgumentException("wrong size in numeric code : not in (1..999)");
      }
   }

   public Iso4217CurrencyCode(String alphabetic) {
      if (alphabetic.length() <= 3) {
         Iso4217CurrencyCode var10000 = this;
         DERPrintableString var2;
         var2 = new DERPrintableString.<init>(alphabetic);
         var10000.obj = var2;
      } else {
         throw new IllegalArgumentException("wrong size in alphabetic code : max size is 3");
      }
   }

   public boolean isAlphabetic() {
      return this.obj instanceof DERPrintableString;
   }

   public String getAlphabetic() {
      return ((DERPrintableString)this.obj).getString();
   }

   public int getNumeric() {
      return ((DERInteger)this.obj).getValue().intValue();
   }

   public DERObject toASN1Object() {
      return this.obj.getDERObject();
   }
}
